==> zio-aws-elasticsearch_3-5.17.104.5-sources.jar: zio/aws/elasticsearch/model/NodeToNodeEncryptionOptions.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class NodeToNodeEncryptionOptions(enabled: Option[Boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions = {
    import NodeToNodeEncryptionOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions.ReadOnly =
    zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions
      .wrap(buildAwsValue())
}
object NodeToNodeEncryptionOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions =
      zio.aws.elasticsearch.model
        .NodeToNodeEncryptionOptions(enabled.map(value => value))
    def enabled: Option[Boolean]
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
  ) extends zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions.ReadOnly {
    override val enabled: Option[Boolean] =
      scala.Option(impl.enabled()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
  ): zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticsearch_3-5.19.31.4-sources.jar: zio/aws/elasticsearch/model/NodeToNodeEncryptionOptions.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class NodeToNodeEncryptionOptions(
    enabled: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions = {
    import NodeToNodeEncryptionOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions.ReadOnly =
    zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions
      .wrap(buildAwsValue())
}
object NodeToNodeEncryptionOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions =
      zio.aws.elasticsearch.model
        .NodeToNodeEncryptionOptions(enabled.map(value => value))
    def enabled: Optional[Boolean]
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
  ) extends zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions.ReadOnly {
    override val enabled: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.NodeToNodeEncryptionOptions
  ): zio.aws.elasticsearch.model.NodeToNodeEncryptionOptions.ReadOnly =
    new Wrapper(impl)
}
